@@ -1,6 +1,5 @@
 #define QT_FEATURE_alsa 1
 #define QT_FEATURE_directshow -1
-#define QT_FEATURE_directshow_player -1
 #define QT_FEATURE_evr -1
 #define QT_FEATURE_gpu_vivante -1
 #define QT_FEATURE_gstreamer_1_0 1
@@ -15,6 +14,5 @@
 #define QT_FEATURE_resourcepolicy -1
 #define QT_FEATURE_wasapi -1
 #define QT_FEATURE_wmf -1
-#define QT_FEATURE_wmf_player -1
 #define QT_FEATURE_wmsdk -1
 #define QT_FEATURE_wshellitem -1
